import SwiftUI
import MapLibre

struct ContentView: UIViewRepresentable {
    let mapViewDelegate = MyMapViewDelegate()
    func makeUIView(context: Context) -> MLNMapView {

        // Create the map view
        let mapView = MLNMapView(frame: .zero)
        mapView.delegate = mapViewDelegate
        mapView.logoView.isHidden = false

        mapView.setCenter(
            CLLocationCoordinate2D(
                latitude: 37.3787244, longitude: -122.1163535), 
            animated: false)

        mapView.setZoomLevel(4, animated: false)
                
        return mapView
    }
    
    func updateUIView(_ mapView: MLNMapView, context: Context) {
        // Update the view if needed
    }
}

class MyMapViewDelegate: NSObject, MLNMapViewDelegate {
    
    func mapViewDidFinishLoadingMap(_ mapView: MLNMapView) {
        let annotation = MLNPointAnnotation()
        annotation.coordinate = CLLocationCoordinate2D(latitude: 37.3787244, longitude: -122.1163535)
        mapView.addAnnotation(annotation)
    }
    
    func mapView(_ mapView: MLNMapView, annotationCanShowCallout annotation: MLNAnnotation) -> Bool {
        return true
    }
    
    func mapView(_ mapView: MLNMapView, viewFor annotation: MLNAnnotation) -> MLNAnnotationView? {
        guard annotation is MLNPointAnnotation else {
            return nil
        }
        
        let reuseIdentifier = "just and id"
        var annotationView = mapView.dequeueReusableAnnotationView(withIdentifier: reuseIdentifier)

        if annotationView == nil {
            let image = "😨".image()!
            let imageView = UIImageView(image: image)
            annotationView = MLNAnnotationView(annotation: annotation, reuseIdentifier: "just and id")
            annotationView?.addSubview(imageView)
            annotationView?.bounds = CGRect(x: 0, y: 0, width: imageView.bounds.size.width, height: imageView.bounds.size.height)
        }
        
        return annotationView
    }
}

extension String {
    func image() -> UIImage? {
        let size = CGSize(width: 42, height: 42)
        UIGraphicsBeginImageContextWithOptions(size, false, 0)
        UIColor.clear.set()
        let rect = CGRect(origin: .zero, size: size)
        UIRectFill(CGRect(origin: .zero, size: size))
        (self as AnyObject).draw(in: rect, withAttributes: [.font: UIFont.systemFont(ofSize: 38)])
        let image = UIGraphicsGetImageFromCurrentImageContext()
        UIGraphicsEndImageContext()
        return image
    }
}
